@@ -17,17 +17,19 @@
 
 #include <stdio.h>
 #include <unistd.h>
+#ifndef _WIN32
 #include <sys/wait.h>
+#endif
 #include <fcntl.h>
 #include "core/class_alloc_lock.h"
 #include "core/cstr.h"
-#include "core/cstr_array.h"
+#include "core/cstr_array_api.h"
 #include "core/encseq.h"
-#include "core/fasta.h"
-#include "core/fileutils.h"
-#include "core/hashmap.h"
+#include "core/fasta_api.h"
+#include "core/fileutils_api.h"
+#include "core/hashmap_api.h"
 #include "core/log.h"
-#include "core/ma.h"
+#include "core/ma_api.h"
 #include "core/md5_fingerprint_api.h"
 #include "core/undef_api.h"
 #include "core/unused_api.h"
@@ -85,6 +87,7 @@ static int get_index_parameterization(GtMatchIteratorLast *mil, GtStr *out,
   return had_err;
 }
 
+#ifndef _WIN32
 static int get_run_parameterization(GtMatchIteratorLast *mil, GtStr *out,
                                     GtStr *lastbinary,
                                     const char *indexname, const char *qryname,
@@ -158,6 +161,7 @@ static int get_run_parameterization(GtMatchIteratorLast *mil, GtStr *out,
   gt_str_append_cstr(out, qryname);
   return had_err;
 }
+#endif
 
 static int last_prepare_fasta_seqs(const char *filename, GtEncseq *encseq,
                                    GtHashmap *desc_to_seqno,
@@ -168,7 +172,7 @@ static int last_prepare_fasta_seqs(const char *filename, GtEncseq *encseq,
   int had_err = 0;
   GtFile *fp;
   GtStr *header = NULL;
-  unsigned long desclen;
+  GtUword desclen;
   gt_assert(filename && encseq);
   gt_error_check(err);
 
@@ -176,7 +180,7 @@ static int last_prepare_fasta_seqs(const char *filename, GtEncseq *encseq,
     had_err = -1;
   header = gt_str_new();
   if (!had_err) {
-    unsigned long i, length, startpos, endpos;
+    GtUword i, length, startpos, endpos;
     for (i = 0; i < gt_encseq_num_of_sequences(encseq); i++) {
       char *desccpy;
       desc = gt_encseq_description(encseq, &desclen, i);
@@ -200,6 +204,7 @@ static int last_prepare_fasta_seqs(const char *filename, GtEncseq *encseq,
   return had_err;
 }
 
+#ifndef _WIN32
 static bool last_parse_comment_line(GtMatchIteratorLast *mil)
 {
   char c;
@@ -213,20 +218,22 @@ static bool last_parse_comment_line(GtMatchIteratorLast *mil)
   }
   return true;
 }
+#endif
 
+#ifndef _WIN32
 static int last_parse_match(GtMatchIteratorLast *mil, GtMatch **match,
                             GtError *err)
 {
   int had_err = 0;
-  unsigned long score = GT_UNDEF_ULONG,
-                start1 = GT_UNDEF_ULONG,
-                start2 = GT_UNDEF_ULONG,
-                mlength1 = GT_UNDEF_ULONG,
-                mlength2 = GT_UNDEF_ULONG,
-                slength1 = GT_UNDEF_ULONG,
-                slength2 = GT_UNDEF_ULONG,
-                seqno1 = GT_UNDEF_ULONG,
-                seqno2 = GT_UNDEF_ULONG;
+  GtUword score = GT_UNDEF_UWORD,
+                start1 = GT_UNDEF_UWORD,
+                start2 = GT_UNDEF_UWORD,
+                mlength1 = GT_UNDEF_UWORD,
+                mlength2 = GT_UNDEF_UWORD,
+                slength1 = GT_UNDEF_UWORD,
+                slength2 = GT_UNDEF_UWORD,
+                seqno1 = GT_UNDEF_UWORD,
+                seqno2 = GT_UNDEF_UWORD;
   char strand1 = GT_UNDEF_CHAR,
        strand2 = GT_UNDEF_CHAR,
        seqid1[BUFSIZ],
@@ -239,23 +246,21 @@ static int last_parse_match(GtMatchIteratorLast *mil, GtMatch **match,
   had_err = gt_str_read_next_line_generic(mil->pvt->linebuf,
                                           mil->pvt->matchfile);
   if (!had_err) {
-    if (11 != sscanf(gt_str_get(mil->pvt->linebuf), "%lu %s %lu %lu %c %lu "
-                                     "%s %lu %lu %c %lu",
-                                     &score,
-                                     seqid1, &start1, &mlength1,
-                                     &strand1, &slength1,
-                                     seqid2, &start2, &mlength2,
-                                     &strand2, &slength2)) {
+    if (11 != sscanf(gt_str_get(mil->pvt->linebuf),
+                     GT_WU " %s " GT_WU " " GT_WU " %c " GT_WU " %s " GT_WU
+                     " " GT_WU " %c " GT_WU,
+                     &score, seqid1, &start1, &mlength1, &strand1, &slength1,
+                     seqid2, &start2, &mlength2, &strand2, &slength2)) {
       gt_error_set(err, "error parsing LAST output: "
                         "could not parse line '%s'",
                    gt_str_get(mil->pvt->linebuf));
       had_err = -1;
     }
     if (!had_err) {
-      seqno1 = (unsigned long) gt_hashmap_get(mil->pvt->desc_to_seqno, seqid1);
-      gt_assert(seqno1 != GT_UNDEF_ULONG);
-      seqno2 = (unsigned long) gt_hashmap_get(mil->pvt->desc_to_seqno, seqid2);
-      gt_assert(seqno2 != GT_UNDEF_ULONG);
+      seqno1 = (GtUword) gt_hashmap_get(mil->pvt->desc_to_seqno, seqid1);
+      gt_assert(seqno1 != GT_UNDEF_UWORD);
+      seqno2 = (GtUword) gt_hashmap_get(mil->pvt->desc_to_seqno, seqid2);
+      gt_assert(seqno2 != GT_UNDEF_UWORD);
       *match = gt_match_last_new(seqid1, seqid2, score,
                                  seqno1, seqno2,
                                  start1, start2,
@@ -266,11 +271,15 @@ static int last_parse_match(GtMatchIteratorLast *mil, GtMatch **match,
   }
   return had_err;
 }
+#endif
 
-static GtMatchIteratorStatus gt_match_iterator_last_next(GtMatchIterator *gmpi,
+static GtMatchIteratorStatus gt_match_iterator_last_next(GT_UNUSED
+                                                         GtMatchIterator *gmpi,
+                                                         GT_UNUSED
                                                          GtMatch **match,
                                                          GtError *err)
 {
+#ifndef _WIN32
   int had_err = 0, rval;
   GtMatchIteratorLast *mil;
   GtStr *tmp = NULL,
@@ -367,6 +376,11 @@ static GtMatchIteratorStatus gt_match_iterator_last_next(GtMatchIterator *gmpi,
     return GT_MATCHER_STATUS_ERROR;
   }
   return GT_MATCHER_STATUS_OK;
+#else
+  /* XXX */
+  gt_error_set(err, "gt_match_iterator_last_next() not implemented");
+  return GT_MATCHER_STATUS_ERROR;
+#endif
 }
 
 static int last_prepare_indices(GtMatchIteratorLast *mil,
@@ -404,23 +418,27 @@ static int last_prepare_indices(GtMatchIteratorLast *mil,
       had_err = last_prepare_fasta_seqs(gt_str_get(mil->pvt->idxfilename),
                                         mil->pvt->es1, mil->pvt->desc_to_seqno,
                                         err);
-      cmdline = gt_str_new();
-      env = getenv("GT_LAST_PATH");
-      if (env) {
-        gt_str_append_cstr(cmdline, env);
-        gt_str_append_cstr(cmdline, "/lastdb ");
-        if (!gt_file_exists(gt_str_get(cmdline))) {
-          gt_error_set(err, "cannot find LASTDB executable at %s",
-                       gt_str_get(cmdline));
-          had_err = -1;
+      if (!had_err) {
+        cmdline = gt_str_new();
+        env = getenv("GT_LAST_PATH");
+        if (env) {
+          gt_str_append_cstr(cmdline, env);
+          gt_str_append_cstr(cmdline, "/lastdb ");
+          if (!gt_file_exists(gt_str_get(cmdline))) {
+            gt_error_set(err, "cannot find LASTDB executable at %s",
+                         gt_str_get(cmdline));
+            had_err = -1;
+          }
+        } else {
+          gt_str_append_cstr(cmdline, "lastdb ");
         }
-      } else {
-        gt_str_append_cstr(cmdline, "lastdb ");
       }
-      gt_str_append_str(cmdline, idxfilename);
-      gt_str_append_cstr(cmdline, " ");
-      gt_str_append_str(cmdline, idxfilename);
-      had_err = system(gt_str_get(cmdline));
+      if (!had_err) {
+        gt_str_append_str(cmdline, idxfilename);
+        gt_str_append_cstr(cmdline, " ");
+        gt_str_append_str(cmdline, idxfilename);
+        had_err = system(gt_str_get(cmdline));
+      }
       if (had_err)
         gt_error_set(err, "error forking the LAST process");
       gt_str_delete(cmdline);
