@@ -18,7 +18,7 @@
 #ifndef GT_GDIFFCALC_H
 #define GT_GDIFFCALC_H
 
-#include "core/tool.h"
+#include "core/tool_api.h"
 
 /* the foo tool */
 GtTool* gt_gdiffcalc(void);
